@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Profile::Perl;
-$ExtUtils::Builder::Profile::Perl::VERSION = '0.004';
+$ExtUtils::Builder::Profile::Perl::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -44,7 +44,7 @@ sub process_linker {
 	my $os = _get_var($config, $opts, 'osname');
 	if ($linker->type eq 'executable' or $linker->type eq 'shared-library' or ($linker->type eq 'loadable-object' and $needs_relinking{$os})) {
 		if ($os eq 'MSWin32') {
-			$linker->add_argument(value => _split_var($config, $opts, 'libperl'));
+			$linker->add_argument(value => _split_var($config, $opts, 'libperl', ranking => $linker->default_library_ranking - 1));
 		}
 		else {
 			my ($libperl, $libext, $so) = map { _get_var($config, $opts, $_) } qw/libperl lib_ext so/;
@@ -79,7 +79,7 @@ ExtUtils::Builder::Profile::Perl - A profile for compiling and linking against p
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
